metadata in database - represented by MetaData class
*
binary media data in real file
*
*
- * @package Campcaster
+ * @package Airtime
* @subpackage StorageServer
* @copyright 2010 Sourcefabric O.P.S.
* @license http://www.gnu.org/licenses/gpl.txt
diff --git a/application/models/Subjects.php b/application/models/Subjects.php
index f99cea1c6..f307d47ac 100644
--- a/application/models/Subjects.php
+++ b/application/models/Subjects.php
@@ -9,7 +9,7 @@ define('ALIBERR_BADSMEMB', 21);
* with "linearized recursive membership" ;)
* (allow adding users to groups or groups to groups)
*
- * @package Campcaster
+ * @package Airtime
* @subpackage Alib
* @copyright 2010 Sourcefabric O.P.S.
* @license http://www.gnu.org/licenses/gpl.txt
@@ -680,4 +680,4 @@ class Subjects {
} // fn test
} // class Subjects
-?>
\ No newline at end of file
+?>
diff --git a/application/models/Transport.php b/application/models/Transport.php
index c5e8ce5dd..151c75a29 100644
--- a/application/models/Transport.php
+++ b/application/models/Transport.php
@@ -38,7 +38,7 @@ include_once("TransportRecord.php");
*
file
*
*
- * @package Campcaster
+ * @package Airtime
* @subpackage StorageServer
* @copyright 2010 Sourcefabric O.P.S.
* @license http://www.gnu.org/licenses/gpl.txt
@@ -401,7 +401,7 @@ class Transport
/* ------------------------------------------------ remote-search methods */
/**
- * Start search job on remote Campcaster instance.
+ * Start search job on remote Airtime instance.
*
* @param array $criteria
* LS criteria format (see localSearch)
@@ -1636,7 +1636,7 @@ class Transport
/**
- * Ping to remote Campcaster server
+ * Ping to remote Airtime server
*
* @return string
* network hub response or error object
diff --git a/application/models/TransportRecord.php b/application/models/TransportRecord.php
index 6c804279c..deafd736f 100644
--- a/application/models/TransportRecord.php
+++ b/application/models/TransportRecord.php
@@ -5,7 +5,7 @@ define('TR_LEAVE_CLOSED', TRUE);
/**
* Auxiliary class for transport records
*
- * @package Campcaster
+ * @package Airtime
* @subpackage StorageServer
* @copyright 2010 Sourcefabric O.P.S.
* @license http://www.gnu.org/licenses/gpl.txt
@@ -416,4 +416,4 @@ class TransportRecord
}
} // class TransportRecord
-?>
\ No newline at end of file
+?>
diff --git a/application/models/Validator.php b/application/models/Validator.php
index d730aee10..87f1eef22 100644
--- a/application/models/Validator.php
+++ b/application/models/Validator.php
@@ -23,7 +23,7 @@ define('VAL_PREDXML', 121);
*
* It probably should be replaced by XML schema validation in the future.
*
- * @package Campcaster
+ * @package Airtime
* @subpackage StorageServer
* @copyright 2010 Sourcefabric O.P.S.
* @license http://www.gnu.org/licenses/gpl.txt
@@ -382,4 +382,4 @@ class Validator {
} // class Validator
-?>
\ No newline at end of file
+?>
diff --git a/application/models/XmlParser.php b/application/models/XmlParser.php
index 7d440460b..8b6f0ef30 100644
--- a/application/models/XmlParser.php
+++ b/application/models/XmlParser.php
@@ -1,6 +1,6 @@
\ No newline at end of file
+?>
diff --git a/application/models/cron/Cron.php b/application/models/cron/Cron.php
index fba702b62..b4b0eb723 100755
--- a/application/models/cron/Cron.php
+++ b/application/models/cron/Cron.php
@@ -18,7 +18,7 @@ require_once (dirname(__FILE__).'/../../conf.php');
* );
* $cron->closeCrontab();
*
- * @package Campcaster
+ * @package Airtime
* @subpackage StorageServer.Cron
*/
class Cron {
@@ -211,4 +211,4 @@ class Cron {
return $this->cronfile.' "'.str_replace('"','\"',serialize($this->params)).'"';
}
}
-?>
\ No newline at end of file
+?>
diff --git a/application/models/cron/CronJob.php b/application/models/cron/CronJob.php
index bcd1c82d6..3f6697121 100755
--- a/application/models/cron/CronJob.php
+++ b/application/models/cron/CronJob.php
@@ -2,7 +2,7 @@
/**
* Cron jobs handling abstract class
*
- * @package Campcaster
+ * @package Airtime
* @subpackage StorageServer.Cron
*/
class CronJob
@@ -14,4 +14,4 @@ class CronJob
{
}
}
-?>
\ No newline at end of file
+?>
diff --git a/application/models/cron/Crontab.php b/application/models/cron/Crontab.php
index 92b40ac38..3bd1f655c 100755
--- a/application/models/cron/Crontab.php
+++ b/application/models/cron/Crontab.php
@@ -11,7 +11,7 @@ define('CRON_EMPTY', 4);
* This class lets you manipulate a user's crontab.
* It lets you add delete update entries easily.
*
- * @package Campcaster
+ * @package Airtime
* @subpackage StorageServer.Cron
*/
class Crontab
@@ -281,4 +281,4 @@ class Crontab
return $returnar;
}
}
-?>
\ No newline at end of file
+?>
diff --git a/application/models/playlistFormat.php b/application/models/playlistFormat.php
index 457feb938..367d5c391 100644
--- a/application/models/playlistFormat.php
+++ b/application/models/playlistFormat.php
@@ -1,6 +1,6 @@
\ No newline at end of file
+?>
diff --git a/application/models/tests/pdoTest.php b/application/models/tests/pdoTest.php
index 3aae4465b..2037d5506 100644
--- a/application/models/tests/pdoTest.php
+++ b/application/models/tests/pdoTest.php
@@ -1,8 +1,11 @@
query($sql3);
var_dump($result3->fetchAll());
-?>
\ No newline at end of file
+?>
diff --git a/application/models/xmlrpc/XR_LocStor.php b/application/models/xmlrpc/XR_LocStor.php
index f8df60978..50077dd39 100644
--- a/application/models/xmlrpc/XR_LocStor.php
+++ b/application/models/xmlrpc/XR_LocStor.php
@@ -4,7 +4,7 @@ require_once(dirname(__FILE__).'/../LocStor.php');
/**
* XML-RPC interface for LocStor class
*
- * @package Campcaster
+ * @package Airtime
* @subpackage StorageServer
* @copyright 2010 Sourcefabric O.P.S.
* @license http://www.gnu.org/licenses/gpl.txt
@@ -12,7 +12,7 @@ require_once(dirname(__FILE__).'/../LocStor.php');
class XR_LocStor extends LocStor {
/* ----------------------------------------------------------- getVersion */
/**
- * Dummy method - only returns Campcaster version
+ * Dummy method - only returns Airtime version
*
* The XML-RPC name of this method is "locstor.getVersion".
*
@@ -242,7 +242,7 @@ class XR_LocStor extends LocStor {
* (returned by subsequent storeAudioClipClose call)
*
*
metadata : string - metadata XML string
- * (as defined in Campcaster::Core::AudioClip Class Reference,
+ * (as defined in Airtime::Core::AudioClip Class Reference,
* examples are in storageServer/var/tests/*.xml)
*
*
fname : string - human readable mnemonic file name
@@ -3830,4 +3830,4 @@ class XR_LocStor extends LocStor {
} // class XR_LocStor
-?>
\ No newline at end of file
+?>
diff --git a/application/models/xmlrpc/put.php b/application/models/xmlrpc/put.php
index 650a5880a..57b9bae93 100644
--- a/application/models/xmlrpc/put.php
+++ b/application/models/xmlrpc/put.php
@@ -23,7 +23,7 @@
*
*
* @see XR_LocStor
- * @package Campcaster
+ * @package Airtime
* @subpackage storageServer
*/
@@ -96,4 +96,4 @@ fclose($fp);
fclose($putdata);
header("HTTP/1.1 200");
-?>
\ No newline at end of file
+?>
diff --git a/application/models/xmlrpc/xrLocStor.php b/application/models/xmlrpc/xrLocStor.php
index fb9acf702..4bfb50fca 100644
--- a/application/models/xmlrpc/xrLocStor.php
+++ b/application/models/xmlrpc/xrLocStor.php
@@ -61,7 +61,7 @@ $locStor = new XR_LocStor();
$methods = array(
'test' => 'Tests toupper and checks sessid, params: '.
'teststring, sessid.',
- 'getVersion' => 'Get version of Campcaster.',
+ 'getVersion' => 'Get version of Airtime.',
// 'authenticate' => 'Checks authentication.',
'login' => 'Login to storage.',
'logout' => 'Logout from storage.',
@@ -169,4 +169,4 @@ foreach ($methods as $method => $description) {
$s = new XML_RPC_Server($defs);
-?>
\ No newline at end of file
+?>
diff --git a/public/js/campcaster/library/advancedsearch.js b/public/js/airtime/library/advancedsearch.js
similarity index 100%
rename from public/js/campcaster/library/advancedsearch.js
rename to public/js/airtime/library/advancedsearch.js
diff --git a/public/js/campcaster/library/context-menu.js b/public/js/airtime/library/context-menu.js
similarity index 100%
rename from public/js/campcaster/library/context-menu.js
rename to public/js/airtime/library/context-menu.js
diff --git a/public/js/campcaster/library/library.js b/public/js/airtime/library/library.js
similarity index 100%
rename from public/js/campcaster/library/library.js
rename to public/js/airtime/library/library.js
diff --git a/public/js/campcaster/library/plupload.js b/public/js/airtime/library/plupload.js
similarity index 100%
rename from public/js/campcaster/library/plupload.js
rename to public/js/airtime/library/plupload.js
diff --git a/public/js/campcaster/library/spl.js b/public/js/airtime/library/spl.js
similarity index 100%
rename from public/js/campcaster/library/spl.js
rename to public/js/airtime/library/spl.js
diff --git a/public/js/campcaster/onready/library.js b/public/js/airtime/onready/library.js
similarity index 100%
rename from public/js/campcaster/onready/library.js
rename to public/js/airtime/onready/library.js
diff --git a/public/js/campcaster/onready/search.js b/public/js/airtime/onready/search.js
similarity index 100%
rename from public/js/campcaster/onready/search.js
rename to public/js/airtime/onready/search.js
diff --git a/public/js/campcaster/playlist/playlist.js b/public/js/airtime/playlist/playlist.js
similarity index 100%
rename from public/js/campcaster/playlist/playlist.js
rename to public/js/airtime/playlist/playlist.js
diff --git a/public/js/campcaster/schedule/schedule.js b/public/js/airtime/schedule/schedule.js
similarity index 100%
rename from public/js/campcaster/schedule/schedule.js
rename to public/js/airtime/schedule/schedule.js
From dcec6bf4b16308b2cfbb45f2f136c053f627548f Mon Sep 17 00:00:00 2001
From: mkonecny
Date: Wed, 5 Jan 2011 12:31:49 -0500
Subject: [PATCH 08/22] -changed references from campcaster to airtime in pypo/
directory
---
build/build.properties | 2 +-
docs/README.txt | 6 +++---
pypo/api_clients/api_client.py | 28 +++++++++++++-------------
pypo/api_clients/api_client_factory.py | 8 ++++----
pypo/config.cfg | 6 +++---
5 files changed, 25 insertions(+), 25 deletions(-)
diff --git a/build/build.properties b/build/build.properties
index 3e7d17c6b..071fae700 100644
--- a/build/build.properties
+++ b/build/build.properties
@@ -1,4 +1,4 @@
-project.home = /home/naomiaro/dev-campcaster/campcaster
+project.home = /path/to/airtime
project.build = ${project.home}/build
#Database driver
diff --git a/docs/README.txt b/docs/README.txt
index 1e3c6df4d..f66f64d0f 100644
--- a/docs/README.txt
+++ b/docs/README.txt
@@ -14,13 +14,13 @@ Setting Up Your VHOST
The following is a sample VHOST you might want to consider for your project.
- DocumentRoot "/home/naomiaro/campcaster-refactor/campcaster/public"
- ServerName campcaster.local
+ DocumentRoot "/home/naomiaro/campcaster-refactor/airtime/public"
+ ServerName airtime.local
# This should be omitted in the production environment
SetEnv APPLICATION_ENV development
-
+
Options Indexes MultiViews FollowSymLinks
AllowOverride All
Order allow,deny
diff --git a/pypo/api_clients/api_client_factory.py b/pypo/api_clients/api_client_factory.py
index 2bc97dc45..4762b0fc7 100644
--- a/pypo/api_clients/api_client_factory.py
+++ b/pypo/api_clients/api_client_factory.py
@@ -1,9 +1,9 @@
-import campcaster_api_client
+import airtime_api_client
import obp_api_client
def create_api_client(config):
- if config["api_client"] == "campcaster":
- return campcaster_api_client.CampcasterApiClient(config)
+ if config["api_client"] == "airtime":
+ return campcaster_api_client.AirtimeApiClient(config)
elif config["api_client"] == "obp":
return obp_api_client.ObpApiClient(config)
-
\ No newline at end of file
+
diff --git a/pypo/config.cfg b/pypo/config.cfg
index 5d012356c..d5b7208bc 100644
--- a/pypo/config.cfg
+++ b/pypo/config.cfg
@@ -5,9 +5,9 @@
# Set the type of client you are using.
# Currently supported types:
# 1) "obp" = Open Broadcast Platform
-# 2) "campcaster"
+# 2) "airtime"
#
-api_client = "campcaster"
+api_client = "airtime"
############################################
# Directories / Hosts #
@@ -66,7 +66,7 @@ cue_style = 'pre'
################################################################################
#####################
-# Campcaster Config #
+# Airtime Config #
#####################
# Value needed to access the API
api_key = 'AAA'
From 9bda47eff4b19e784e6df291a609579e0b4345b9 Mon Sep 17 00:00:00 2001
From: mkonecny
Date: Wed, 5 Jan 2011 14:18:03 -0500
Subject: [PATCH 09/22] -changed file names and comments from campcaster to
airtime in utils/ folder
---
utils/CleanStor.sh | 10 +++++-----
utils/{campcaster-backup => airtime-backup} | 14 +++++++-------
.../{campcaster-backup.php => airtime-backup.php} | 0
utils/{campcaster-import => airtime-import} | 12 ++++++------
.../{campcaster-import.php => airtime-import.php} | 12 ++++++------
utils/{campcaster-restore => airtime-restore} | 12 ++++++------
utils/resetStorage.sh | 8 ++++----
utils/serbianLatinToCyrillicConverter.py | 8 ++++----
8 files changed, 38 insertions(+), 38 deletions(-)
rename utils/{campcaster-backup => airtime-backup} (88%)
rename utils/{campcaster-backup.php => airtime-backup.php} (100%)
rename utils/{campcaster-import => airtime-import} (79%)
rename utils/{campcaster-import.php => airtime-import.php} (97%)
rename utils/{campcaster-restore => airtime-restore} (90%)
diff --git a/utils/CleanStor.sh b/utils/CleanStor.sh
index 5a5ac5bd8..859f67fb0 100755
--- a/utils/CleanStor.sh
+++ b/utils/CleanStor.sh
@@ -2,25 +2,25 @@
#-------------------------------------------------------------------------------
# Copyright (c) 2010 Sourcefabric O.P.S.
#
-# This file is part of the Campcaster project.
+# This file is part of the Airtime project.
# http://campcaster.sourcefabric.org/
#
-# Campcaster is free software; you can redistribute it and/or modify
+# Airtime is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
-# Campcaster is distributed in the hope that it will be useful,
+# Airtime is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Campcaster; if not, write to the Free Software
+# along with Airtime; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#-------------------------------------------------------------------------------
#-------------------------------------------------------------------------------
-# This script cleans audio files in the Campcaster storageServer.
+# This script cleans audio files in the Airtime storageServer.
php -q CleanStor.php "$@" || exit 1
diff --git a/utils/campcaster-backup b/utils/airtime-backup
similarity index 88%
rename from utils/campcaster-backup
rename to utils/airtime-backup
index fbfe430c3..fd681b8dc 100755
--- a/utils/campcaster-backup
+++ b/utils/airtime-backup
@@ -2,26 +2,26 @@
#-------------------------------------------------------------------------------
# Copyright (c) 2010 Sourcefabric O.P.S.
#
-# This file is part of the Campcaster project.
+# This file is part of the Airtime project.
# http://campcaster.sourcefabric.org/
#
-# Campcaster is free software; you can redistribute it and/or modify
+# Airtime is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
-# Campcaster is distributed in the hope that it will be useful,
+# Airtime is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Campcaster; if not, write to the Free Software
+# along with Airtime; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#-------------------------------------------------------------------------------
#-------------------------------------------------------------------------------
-# This script creates a tgz archive of the Campcaster storage.
+# This script creates a tgz archive of the Airtime storage.
#
# To get usage help, try the -h option
#-------------------------------------------------------------------------------
@@ -44,7 +44,7 @@ destfile="storage$datestr.tar"
#-------------------------------------------------------------------------------
printUsage()
{
- echo "This script creates a tgz archive of the Campcaster storage.";
+ echo "This script creates a tgz archive of the Airtime storage.";
echo "parameters:";
echo "";
echo " -d, --destination Destination directory [default:$tmpmaindir].";
@@ -91,7 +91,7 @@ tmpdir=`mktemp -d $tmpmaindir/tmp.XXXXXX`
echo "Backuping to $destdir/$destfile :"
echo "Dumping database ..."
cd $phpdir
-php -q campcaster_backup.php > $tmpdir/$dbxml
+php -q airtime_backup.php > $tmpdir/$dbxml
echo "Packaging stored files ..."
cd $phpdir
storpath=`php -q getStorPath.php`
diff --git a/utils/campcaster-backup.php b/utils/airtime-backup.php
similarity index 100%
rename from utils/campcaster-backup.php
rename to utils/airtime-backup.php
diff --git a/utils/campcaster-import b/utils/airtime-import
similarity index 79%
rename from utils/campcaster-import
rename to utils/airtime-import
index 55c6b3628..38713c60b 100755
--- a/utils/campcaster-import
+++ b/utils/airtime-import
@@ -2,26 +2,26 @@
#-------------------------------------------------------------------------------
# Copyright (c) 2010 Sourcefabric O.P.S.
#
-# This file is part of the Campcaster project.
+# This file is part of the Airtime project.
# http://campcaster.sourcefabric.org/
#
-# Campcaster is free software; you can redistribute it and/or modify
+# Airtime is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
-# Campcaster is distributed in the hope that it will be useful,
+# Airtime is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Campcaster; if not, write to the Free Software
+# along with Airtime; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#-------------------------------------------------------------------------------
#-------------------------------------------------------------------------------
-# This script imports audio files to the Campcaster storageServer.
+# This script imports audio files to the Airtime storageServer.
#
# To get usage help, try the -h option
#-------------------------------------------------------------------------------
@@ -40,4 +40,4 @@ invokePwd=$PWD
#echo $invokePwd
cd $phpdir
-php -q campcaster-import.php --dir "$invokePwd" "$@" || exit 1
+php -q airtime-import.php --dir "$invokePwd" "$@" || exit 1
diff --git a/utils/campcaster-import.php b/utils/airtime-import.php
similarity index 97%
rename from utils/campcaster-import.php
rename to utils/airtime-import.php
index 8cb92dcf3..d6c74d4b2 100644
--- a/utils/campcaster-import.php
+++ b/utils/airtime-import.php
@@ -2,7 +2,7 @@
/**
* Mass import of audio files.
*
- * @package Campcaster
+ * @package Airtime
* @subpackage StorageAdmin
* @copyright 2010 Sourcefabric O.P.S.
* @license http://www.gnu.org/licenses/gpl.txt
@@ -27,7 +27,7 @@ function camp_import_error_handler()
function printUsage()
{
global $CC_CONFIG;
- echo "There are two ways to import audio files into Campcaster: linking\n";
+ echo "There are two ways to import audio files into Airtime: linking\n";
echo "or copying.\n";
echo "\n";
echo "Linking has the advantage that it will not duplicate any files,\n";
@@ -40,13 +40,13 @@ function printUsage()
echo "your files.\n";
echo "\n";
echo "Usage:\n";
- echo " campcaster-import [OPTIONS] FILES_OR_DIRS\n";
+ echo " airtime-import [OPTIONS] FILES_OR_DIRS\n";
echo "\n";
echo "Options:\n";
echo " -l, --link Link to specified files.\n";
echo " Saves storage space, but you cannot move, delete,\n";
echo " or rename the original files, otherwise there will\n";
- echo " be dead air when Campcaster tries to play the file.\n";
+ echo " be dead air when Airtime tries to play the file.\n";
echo "\n";
echo " -c, --copy Copy the specified files.\n";
echo " This is useful if you are importing from removable media.\n";
@@ -228,7 +228,7 @@ function camp_import_audio_file($p_filepath, $p_importMode = null, $p_testOnly =
$DEBUG_IMPORT = false;
echo "========================\n";
-echo "Campcaster Import Script\n";
+echo "Airtime Import Script\n";
echo "========================\n";
$g_errors = 0;
//print_r($argv);
@@ -350,4 +350,4 @@ if ($g_errors > 0) {
echo " *** Total: ".($g_fileCount+$g_duplicates)." files in $time seconds = $speed files/second.\n";
echo "==========================================================================\n";
-?>
\ No newline at end of file
+?>
diff --git a/utils/campcaster-restore b/utils/airtime-restore
similarity index 90%
rename from utils/campcaster-restore
rename to utils/airtime-restore
index 69bfe8383..066c36050 100755
--- a/utils/campcaster-restore
+++ b/utils/airtime-restore
@@ -2,26 +2,26 @@
#-------------------------------------------------------------------------------
# Copyright (c) 2010 Sourcefabric O.P.S.
#
-# This file is part of the Campcaster project.
+# This file is part of the Airtime project.
# http://campcaster.sourcefabric.org/
#
-# Campcaster is free software; you can redistribute it and/or modify
+# Airtime is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
-# Campcaster is distributed in the hope that it will be useful,
+# Airtime is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Campcaster; if not, write to the Free Software
+# along with Airtime; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#-------------------------------------------------------------------------------
#-------------------------------------------------------------------------------
-# This script restores the data which was backed up with campcaster-backup.
+# This script restores the data which was backed up with airtime-backup.
#
# To get usage help, try the -h option
#-------------------------------------------------------------------------------
@@ -42,7 +42,7 @@ tarfile0="xmls.tar"
#-------------------------------------------------------------------------------
printUsage()
{
- echo "This script restores the data which was backed up with campcaster-backup."
+ echo "This script restores the data which was backed up with airtime-backup."
echo "parameters:";
echo "";
echo " -f, --file File with the backed up data, required.";
diff --git a/utils/resetStorage.sh b/utils/resetStorage.sh
index af1448766..1006e1295 100755
--- a/utils/resetStorage.sh
+++ b/utils/resetStorage.sh
@@ -2,22 +2,22 @@
#-------------------------------------------------------------------------------
# Copyright (c) 2010 Sourcefabric O.P.S.
#
-# This file is part of the Campcaster project.
+# This file is part of the Airtime project.
# http://campcaster.sourcefabric.org/
# To report bugs, send an e-mail to bugs@campware.org
#
-# Campcaster is free software; you can redistribute it and/or modify
+# Airtime is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
-# Campcaster is distributed in the hope that it will be useful,
+# Airtime is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Campcaster; if not, write to the Free Software
+# along with Airtime; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#-------------------------------------------------------------------------------
diff --git a/utils/serbianLatinToCyrillicConverter.py b/utils/serbianLatinToCyrillicConverter.py
index e68118995..3cb49283d 100755
--- a/utils/serbianLatinToCyrillicConverter.py
+++ b/utils/serbianLatinToCyrillicConverter.py
@@ -3,22 +3,22 @@
#-------------------------------------------------------------------------------
# Copyright (c) 2010 Sourcefabric O.P.S.
#
-# This file is part of the Campcaster project.
+# This file is part of the Airtime project.
# http://campcaster.sourcefabric.org/
# To report bugs, send an e-mail to bugs@campware.org
#
-# Campcaster is free software; you can redistribute it and/or modify
+# Airtime is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
-# Campcaster is distributed in the hope that it will be useful,
+# Airtime is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Campcaster; if not, write to the Free Software
+# along with Airtime; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
From 11a30ab37efe3c0d3dbfb4532f784a721ef6651a Mon Sep 17 00:00:00 2001
From: mkonecny
Date: Wed, 5 Jan 2011 14:25:58 -0500
Subject: [PATCH 10/22] -changed campcaster to airtime strings in library/
directory
---
library/getid3/bin/autogen.sh | 8 ++++----
library/getid3/configure | 10 +++++-----
library/getid3/etc/Makefile.in | 8 ++++----
library/getid3/etc/configure.ac | 8 ++++----
library/getid3/etc/doxygen.config | 8 ++++----
5 files changed, 21 insertions(+), 21 deletions(-)
diff --git a/library/getid3/bin/autogen.sh b/library/getid3/bin/autogen.sh
index 89c606735..f2f0a70d8 100755
--- a/library/getid3/bin/autogen.sh
+++ b/library/getid3/bin/autogen.sh
@@ -2,21 +2,21 @@
#-------------------------------------------------------------------------------
# Copyright (c) 2010 Sourcefabric O.P.S.
#
-# This file is part of the Campcaster project.
+# This file is part of the Airtime project.
# http://campcaster.sourcefabric.org/
#
-# Campcaster is free software; you can redistribute it and/or modify
+# Airtime is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
-# Campcaster is distributed in the hope that it will be useful,
+# Airtime is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Campcaster; if not, write to the Free Software
+# along with Airtime; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#-------------------------------------------------------------------------------
diff --git a/library/getid3/configure b/library/getid3/configure
index 0c58cc366..2c4a059eb 100755
--- a/library/getid3/configure
+++ b/library/getid3/configure
@@ -2,21 +2,21 @@
#-------------------------------------------------------------------------------
# Copyright (c) 2010 Sourcefabric O.P.S.
#
-# This file is part of the Campcaster project.
-# http://campcaster.campware.org/
+# This file is part of the Airtime project.
+# http://campcaster.sourcefabric.org/
#
-# Campcaster is free software; you can redistribute it and/or modify
+# Airtime is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
-# Campcaster is distributed in the hope that it will be useful,
+# Airtime is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Campcaster; if not, write to the Free Software
+# along with Airtime; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#-------------------------------------------------------------------------------
diff --git a/library/getid3/etc/Makefile.in b/library/getid3/etc/Makefile.in
index 0e42713e1..460a967ab 100644
--- a/library/getid3/etc/Makefile.in
+++ b/library/getid3/etc/Makefile.in
@@ -2,21 +2,21 @@
# getID3 - read and writes tags in media files - see getid3.readme.txt
# getID3 by James Heinrich
#
-# This file is part of the Campcaster project.
+# This file is part of the Airtime project.
# Copyright (c) 2010 Sourcefabric O.P.S.
#
-# Campcaster is free software; you can redistribute it and/or modify
+# Airtime is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
-# Campcaster is distributed in the hope that it will be useful,
+# Airtime is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Campcaster; if not, write to the Free Software
+# along with Airtime; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
# @configure_input@
diff --git a/library/getid3/etc/configure.ac b/library/getid3/etc/configure.ac
index 196f64df4..15e716f45 100644
--- a/library/getid3/etc/configure.ac
+++ b/library/getid3/etc/configure.ac
@@ -1,21 +1,21 @@
dnl-----------------------------------------------------------------------------
dnl Copyright (c) 2010 Sourcefabric O.P.S.
dnl
-dnl This file is part of the Campcaster project.
+dnl This file is part of the Airtime project.
dnl http://campcaster.sourcefabric.org/
dnl
-dnl Campcaster is free software; you can redistribute it and/or modify
+dnl Airtime is free software; you can redistribute it and/or modify
dnl it under the terms of the GNU General Public License as published by
dnl the Free Software Foundation; either version 2 of the License, or
dnl (at your option) any later version.
dnl
-dnl Campcaster is distributed in the hope that it will be useful,
+dnl Airtime is distributed in the hope that it will be useful,
dnl but WITHOUT ANY WARRANTY; without even the implied warranty of
dnl MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
dnl GNU General Public License for more details.
dnl
dnl You should have received a copy of the GNU General Public License
-dnl along with Campcaster; if not, write to the Free Software
+dnl along with Airtime; if not, write to the Free Software
dnl Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
dnl
dnl-----------------------------------------------------------------------------
diff --git a/library/getid3/etc/doxygen.config b/library/getid3/etc/doxygen.config
index 6244f1311..2db2ff22b 100644
--- a/library/getid3/etc/doxygen.config
+++ b/library/getid3/etc/doxygen.config
@@ -2,20 +2,20 @@
# doxygen.config
# Copyright (c) 2010 Sourcefabric O.P.S.
#
-# This file is part of the Campcaster project.
+# This file is part of the Airtime project.
#
-# Campcaster is free software; you can redistribute it and/or modify
+# Airtime is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
-# Campcaster is distributed in the hope that it will be useful,
+# Airtime is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Campcaster; if not, write to the Free Software
+# along with Airtime; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#-------------------------------------------------------------------------------
From d06956ec5b61506dfccf0ce05e3292d5ec1b3734 Mon Sep 17 00:00:00 2001
From: mkonecny
Date: Wed, 5 Jan 2011 16:39:32 -0500
Subject: [PATCH 11/22] -changed filenames and documentation from campcaster to
airtime
---
CREDITS | 10 +++++++++-
INSTALL | 8 ++++----
README | 2 ++
debian/rules | 2 +-
install/{campcaster-user.php => airtime-user.php} | 0
install/postInstallStation.sh | 2 +-
...schedule-insert.php => airtime-schedule-insert.php} | 0
7 files changed, 17 insertions(+), 7 deletions(-)
rename install/{campcaster-user.php => airtime-user.php} (100%)
rename pypo/tests/{campcaster-schedule-insert.php => airtime-schedule-insert.php} (100%)
diff --git a/CREDITS b/CREDITS
index ffa2ce2b6..e3c5f3a1d 100644
--- a/CREDITS
+++ b/CREDITS
@@ -6,7 +6,9 @@ Version 1.6.0
-------------
This version marks a major change to the project, completely replacing the
custom audio player with liquidsoap, dropping the custom desktop GUI, and
-completely rewriting the web interface.
+completely rewriting the web interface. It also marks the beginning of
+preparation for the name change from "Campcaster" to "Airtime" for the major
+2.0 release.
Paul Baranowski (paul.baranowski@sourcefabric.org)
Role: Project Lead / Software Developer
@@ -20,6 +22,12 @@ Naomi Aro (naomi.aro@sourcefabric.org)
- New User Interface
- Conversion to Propel DB backend
+Martin Konecny (martin.konecny@sourcefabric.org)
+ Role:Software Developer
+ Highlights:
+ - New User Interface
+ - Scheduler
+
Daniel James
Role: Documentor & QA
diff --git a/INSTALL b/INSTALL
index 654f8ff4e..9da745be8 100644
--- a/INSTALL
+++ b/INSTALL
@@ -2,22 +2,22 @@
Copyright (c) 2010 Sourcefabric O.P.S.
- This file is part of the Campcaster project.
+ This file is part of the Airtime project.
http://campcaster.sourcefabric.org/
To report bugs, send an e-mail to contact@sourcefabric.org
- Campcaster is free software; you can redistribute it and/or modify
+ Airtime is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
- Campcaster is distributed in the hope that it will be useful,
+ Airtime is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
- along with Campcaster; if not, write to the Free Software
+ along with Airtime; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
--------------------------------------------------------------------------------
diff --git a/README b/README
index c1f2d1ff5..7aa7ee4ad 100644
--- a/README
+++ b/README
@@ -1,3 +1,5 @@
+-WARNING THIS FILE IS OUT OF DATE!!!! references to gstreamer etc. - mk
+
=========================================================================
========================== CAMPCASTER ===============================
=========================================================================
diff --git a/debian/rules b/debian/rules
index 54c51876e..057f36fa9 100755
--- a/debian/rules
+++ b/debian/rules
@@ -139,7 +139,7 @@ override_dh_install:
override_dh_fixperms:
dh_fixperms
#
- chmod +x debian/campcaster-data/usr/share/campcaster/www/storageServer/var/install/campcaster-user.php
+ chmod +x debian/campcaster-data/usr/share/campcaster/www/storageServer/var/install/airtime-user.php
chmod -x debian/campcaster-data/usr/share/campcaster/www/storageServer/var/cron/Crontab.php \
debian/campcaster-data/usr/share/campcaster/www/storageServer/var/cron/CronJob.php \
debian/campcaster-data/usr/share/campcaster/www/htmlUI/var/templates/popup/PLAYLIST.downloadExportedFile.tpl \
diff --git a/install/campcaster-user.php b/install/airtime-user.php
similarity index 100%
rename from install/campcaster-user.php
rename to install/airtime-user.php
diff --git a/install/postInstallStation.sh b/install/postInstallStation.sh
index 0539ec713..42e59b894 100755
--- a/install/postInstallStation.sh
+++ b/install/postInstallStation.sh
@@ -404,7 +404,7 @@ if [ "$storage_is_local" = "yes" ]; then
grep -q 'ls_scheduler_storage_pass' $install_etc/campcaster-scheduler.xml
if [ $? = 0 ]; then
SCHEDULER_STORAGE_PASS=`pwgen -N1 -c -n -s`
- php -q $install_var_ls/storageServer/var/install/campcaster-user.php \
+ php -q $install_var_ls/storageServer/var/install/airtime-user.php \
--addupdate scheduler ${SCHEDULER_STORAGE_PASS}
sed -i -e "s/ls_scheduler_storage_pass/${SCHEDULER_STORAGE_PASS}/" \
$install_etc/campcaster-scheduler.xml
diff --git a/pypo/tests/campcaster-schedule-insert.php b/pypo/tests/airtime-schedule-insert.php
similarity index 100%
rename from pypo/tests/campcaster-schedule-insert.php
rename to pypo/tests/airtime-schedule-insert.php
From 4717c2008e086a8da6827bc18f4bd7438e4d5b45 Mon Sep 17 00:00:00 2001
From: Paul Baranowski
Date: Wed, 5 Jan 2011 17:41:01 -0500
Subject: [PATCH 12/22] Fixed docs for new name.
---
CREDITS | 5 ++--
README | 77 ++++++++++-----------------------------------------------
2 files changed, 15 insertions(+), 67 deletions(-)
diff --git a/CREDITS b/CREDITS
index e3c5f3a1d..801f38ef4 100644
--- a/CREDITS
+++ b/CREDITS
@@ -6,9 +6,8 @@ Version 1.6.0
-------------
This version marks a major change to the project, completely replacing the
custom audio player with liquidsoap, dropping the custom desktop GUI, and
-completely rewriting the web interface. It also marks the beginning of
-preparation for the name change from "Campcaster" to "Airtime" for the major
-2.0 release.
+completely rewriting the web interface. The project has also been renamed
+from "Campcaster" to "Airtime" for this release.
Paul Baranowski (paul.baranowski@sourcefabric.org)
Role: Project Lead / Software Developer
diff --git a/README b/README
index 7aa7ee4ad..12d5f96e4 100644
--- a/README
+++ b/README
@@ -1,96 +1,45 @@
--WARNING THIS FILE IS OUT OF DATE!!!! references to gstreamer etc. - mk
-
=========================================================================
-========================== CAMPCASTER ===============================
+========================== AIRTIME =================================
=========================================================================
-Campcaster is the first free and open radio management software that
-provides live studio broadcast capabilities as well as remote automation
-in one integrated system.
+Airtime is an open source application that provides remote automation
+of a radio station.
-Campcaster has three audio outputs: one for live broadcasting, one for
-previewing audio, and one for automated scheduled playback.
-
-Major features of Campcaster:
- * Live, in-studio playout. Campcaster Studio enables station personnel
- to play out both individual sound files and playlists such as
- advertising blocks or entire programs.
+Major features:
* Web-based remote station management. Authorized personnel can add
program material, create playlists, and schedule programming all via
- Campcaster's web interface.
- * Automation. Campcaster has a scheduler function that enables users to
+ a web interface.
+ * Automation. Airtime has a scheduler function that enables users to
set playlists for playback at a date and time of their choosing.
Playlists can be played back multiple times.
- * Playlists. Campcaster allows users to create playlists that can be
+ * Playlists. Airtime allows users to create playlists that can be
either played on-demand in the Studio or in automated mode. Playlists
can be nested inside each other, so for example, a playlist with a
block of ads can be inside of a playlist with a music program.
* Centralized archives of station program material. Station personnel
have a searchable, browseable central archive that is accessible both
in the office and via the web.
- * Solid, fast playback. Campcaster uses the popular Gstreamer
+ * Solid, fast playback. Airtime uses the open source Liquidsoap
multimedia framework for clean, reliable, fast playback.
- * Program sharing. Stations can share both playlists and files with a
- designated, centralized 'network hub.' This enables the creation of
- 'virtual radio networks' connected via the Internet.
- * Search-based backup. You can backup all station archives at the click
- of a button, or only backup certain files based on search terms, so
- that backup files can be made of only a certain program or of all
- files created by a certain user.
- * Localization. Campcaster is multilingual and supports Unicode. It
- also is very easy to create language localizations.
- * No restrictions. Multiple instances of the Campcaster Studio program
- can access the same archive on the office network, and there are no
- worries about hardware dongles or keys limiting access on multiple PCs.
- * Innovative design. Campcaster's user interface – the product of
- Parsons School of Design's “Design and Communication” program -
- introduces a number of innovations, including the 'Scratchpad',
- a list of recently-used files and playlists.
* Open, extensible architecture. Stations are free to extend and alter
- all parts of the Campcaster program code, which makes extensive use
- of XML-RPC APIs.
+ all parts of the program code.
INSTALLATION
------------
Please see this page for a typical user installation:
-http://en.flossmanuals.net/Campcaster
+http://en.flossmanuals.net/Airtime
If you are a developer, please see this page:
-http://wiki.sourcefabric.org/display/CC/Campcaster+Dev+Site
+http://wiki.sourcefabric.org/display/CC/Airtime+Dev+Site
Quick links to our resources
----------------------------
- User Manual: http://en.flossmanuals.net/Campcaster/Introduction
+ User Manual: http://en.flossmanuals.net/Airtime/Introduction
Forums and mailing lists: http://forum.sourcefabric.org
Bug Tracking: http://dev.sourcefabric.org
Code view/review: http://code.sourcefabric.org
Public source code hosting: http://github.com/sourcefabric
- Download link: https://sourceforge.net/projects/campcaster/files/
+ Download link: https://sourceforge.net/projects/airtime/files/
Developer's wiki: http://wiki.sourcefabric.org
-
--------------------------------------------------------------------------
-
- Copyright (c) 2010 Sourcefabric O.P.S.
-
- This file is part of the Campcaster project.
- http://campcaster.sourcefabric.org/
- To report bugs, send an e-mail to campcaster-support@lists.sourcefabric.org
-
- Campcaster is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- Campcaster is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with Campcaster; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-
--------------------------------------------------------------------------
-
From fe87d8957bb50f20a9cc02c922d480fc7e6c80d3 Mon Sep 17 00:00:00 2001
From: mkonecny
Date: Wed, 5 Jan 2011 17:44:23 -0500
Subject: [PATCH 13/22] -check if user=root for propel-install script
---
install/airtime-user.php | 6 +++---
install/postInstallStation.sh | 10 +++++-----
install/propel-install.php | 11 ++++++++---
install/uninstall.php | 4 ++--
4 files changed, 18 insertions(+), 13 deletions(-)
diff --git a/install/airtime-user.php b/install/airtime-user.php
index 399887da1..ea591fd7e 100644
--- a/install/airtime-user.php
+++ b/install/airtime-user.php
@@ -17,9 +17,9 @@ if (isset($arr["DOCUMENT_ROOT"]) && ($arr["DOCUMENT_ROOT"] != "") ) {
function printUsage()
{
echo "\n";
- echo "campcaster-user\n";
+ echo "airtime-user\n";
echo "===============\n";
- echo " This program allows you to manage Campcaster users.\n";
+ echo " This program allows you to manage Airtime users.\n";
echo "\n";
echo "OPTIONS:\n";
echo " --addupdate \n";
@@ -99,4 +99,4 @@ if (PEAR::isError($r)) {
die($r->getMessage());
}
exit(0);
-?>
\ No newline at end of file
+?>
diff --git a/install/postInstallStation.sh b/install/postInstallStation.sh
index 42e59b894..adbff96d2 100755
--- a/install/postInstallStation.sh
+++ b/install/postInstallStation.sh
@@ -1,23 +1,23 @@
#!/bin/bash
#-------------------------------------------------------------------------------
-# Copyright (c) 2010 Sourcefabric O.P.S.
+# Copyright (c) 2010 Airtime O.P.S.
#
-# This file is part of the Campcaster project.
+# This file is part of the Airtime project.
# http://campcaster.sourcefabric.org/
# To report bugs, send an e-mail to bugs@campware.org
#
-# Campcaster is free software; you can redistribute it and/or modify
+# Airtime is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
-# Campcaster is distributed in the hope that it will be useful,
+# Airtime is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Campcaster; if not, write to the Free Software
+# along with Airtime; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#-------------------------------------------------------------------------------
diff --git a/install/propel-install.php b/install/propel-install.php
index 861b004aa..a9960c9d2 100644
--- a/install/propel-install.php
+++ b/install/propel-install.php
@@ -1,6 +1,6 @@
/dev/null";
+$command = __DIR__."/../utils/airtime-import --copy ../audio_samples/ > /dev/null";
@exec($command, $output, $results);
echo "****************************** Install Complete ******************************\n";
diff --git a/install/uninstall.php b/install/uninstall.php
index bef99bb8c..7a2fef3cf 100644
--- a/install/uninstall.php
+++ b/install/uninstall.php
@@ -1,6 +1,6 @@
\ No newline at end of file
+?>
From 7e96572aeecd60174640203e77ecd6953198e6bd Mon Sep 17 00:00:00 2001
From: mkonecny
Date: Wed, 5 Jan 2011 19:05:57 -0500
Subject: [PATCH 14/22] -updated to use new database name, login and passwd
(all 3 are "airtime"). You may delete old database by typing "dropdb -U
campcaster -h localhost campcaster"
---
application/configs/application.ini | 6 +++---
application/configs/conf.php | 8 ++++----
application/configs/propel-config.php | 4 ++--
build/build.properties | 2 +-
public/js/playlist/playlist.js | 2 +-
utils/airtime-import.php | 6 +++---
6 files changed, 14 insertions(+), 14 deletions(-)
diff --git a/application/configs/application.ini b/application/configs/application.ini
index 88feac347..836d659da 100644
--- a/application/configs/application.ini
+++ b/application/configs/application.ini
@@ -12,9 +12,9 @@ resources.view[] =
resources.db.adapter = "Pdo_Pgsql"
resources.db.params.charset = "utf8"
resources.db.params.host = "localhost"
-resources.db.params.username = "campcaster"
-resources.db.params.password = "campcaster"
-resources.db.params.dbname = "campcaster"
+resources.db.params.username = "airtime"
+resources.db.params.password = "airtime"
+resources.db.params.dbname = "airtime"
[staging : production]
diff --git a/application/configs/conf.php b/application/configs/conf.php
index 7779721b5..c46d38b69 100644
--- a/application/configs/conf.php
+++ b/application/configs/conf.php
@@ -8,11 +8,11 @@ global $CC_CONFIG;
$CC_CONFIG = array(
// Database config
'dsn' => array(
- 'username' => 'campcaster',
- 'password' => 'campcaster',
+ 'username' => 'airtime',
+ 'password' => 'airtime',
'hostspec' => 'localhost',
'phptype' => 'pgsql',
- 'database' => 'campcaster',
+ 'database' => 'airtime',
),
// Name of the web server user
@@ -173,4 +173,4 @@ set_include_path('.'.PATH_SEPARATOR.$CC_CONFIG['pearPath']
//$CC_DBC->setFetchMode(DB_FETCHMODE_ASSOC);
-?>
\ No newline at end of file
+?>
diff --git a/application/configs/propel-config.php b/application/configs/propel-config.php
index 768c5b151..1860e1090 100644
--- a/application/configs/propel-config.php
+++ b/application/configs/propel-config.php
@@ -9,7 +9,7 @@ $conf = array (
'adapter' => 'pgsql',
'connection' =>
array (
- 'dsn' => 'pgsql:host=localhost;port=5432;dbname=campcaster;user=campcaster;password=campcaster',
+ 'dsn' => 'pgsql:host=localhost;port=5432;dbname=airtime;user=airtime;password=airtime',
),
),
'default' => 'campcaster',
@@ -17,4 +17,4 @@ $conf = array (
'generator_version' => '1.5.2',
);
$conf['classmap'] = include(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'classmap-propel-config.php');
-return $conf;
\ No newline at end of file
+return $conf;
diff --git a/build/build.properties b/build/build.properties
index 071fae700..02554bf8b 100644
--- a/build/build.properties
+++ b/build/build.properties
@@ -3,7 +3,7 @@ project.build = ${project.home}/build
#Database driver
propel.database = pgsql
-propel.database.url = pgsql:host=localhost dbname=campcaster user=campcaster password=campcaster
+propel.database.url = pgsql:host=localhost dbname=airtime user=airtime password=airtime
#Project name
propel.project = campcaster
diff --git a/public/js/playlist/playlist.js b/public/js/playlist/playlist.js
index 064864205..55f6681fd 100644
--- a/public/js/playlist/playlist.js
+++ b/public/js/playlist/playlist.js
@@ -145,7 +145,7 @@
}
function getScheduleFromServer(){
- $.ajax({ url: "http://localhost/Schedule/get-current-playlist/format/json", dataType:"json", success:function(data){
+ $.ajax({ url: "/Schedule/get-current-playlist/format/json", dataType:"json", success:function(data){
parseItems(data.entries);
}});
setTimeout(getScheduleFromServer, 5000);
diff --git a/utils/airtime-import.php b/utils/airtime-import.php
index d6c74d4b2..21d47e2de 100644
--- a/utils/airtime-import.php
+++ b/utils/airtime-import.php
@@ -238,11 +238,11 @@ if ($DEBUG_IMPORT) {
$testonly = false;
$importMode = "link";
$files = array("/path/to/your/test/file.mp3");
- $dsn = array('username' => 'campcaster',
- 'password' => 'campcaster',
+ $dsn = array('username' => 'airtime',
+ 'password' => 'airtime',
'hostspec' => 'localhost',
'phptype' => 'pgsql',
- 'database' => 'campcaster');
+ 'database' => 'airtime');
} else {
$dsn = $CC_CONFIG['dsn'];
}
From ff02a425147218a4644a5594991f616b7d89c764 Mon Sep 17 00:00:00 2001
From: naomiaro
Date: Thu, 6 Jan 2011 00:23:22 -0500
Subject: [PATCH 15/22] quick search is working, with small paginator ajax url
hack
---
application/controllers/LibraryController.php | 52 +++++++++++++------
application/models/StoredFile.php | 10 ++--
public/js/campcaster/library/quicksearch.js | 10 +++-
3 files changed, 50 insertions(+), 22 deletions(-)
diff --git a/application/controllers/LibraryController.php b/application/controllers/LibraryController.php
index 56770c1da..831147cee 100644
--- a/application/controllers/LibraryController.php
+++ b/application/controllers/LibraryController.php
@@ -37,6 +37,10 @@ class LibraryController extends Zend_Controller_Action
unset($this->search_sess->page);
unset($this->search_sess->md);
+
+ if ($this->getRequest()->isGet()) {
+ unset($this->search_sess->quick);
+ }
$this->_helper->actionStack('contents', 'library');
$this->_helper->actionStack('quick-search', 'library');
@@ -154,14 +158,25 @@ class LibraryController extends Zend_Controller_Action
$currpage = isset($page) ? $page : $last_page;
$this->search_sess->page = $currpage;
- $md = isset($this->search_sess->md) ? $this->search_sess->md : array();
-
- $count = StoredFile::searchFiles($md, $order, true);
+ if(isset($this->search_sess->md)){
+ $md = $this->search_sess->md;
+ $quick = false;
+ }
+ else if(isset($this->search_sess->quick)) {
+ $md = $this->search_sess->quick;
+ $quick = true;
+ }
+ else {
+ $md = array();
+ $quick = false;
+ }
+
+ $count = StoredFile::searchFiles($md, $order, true, null, null, $quick);
$paginator = new Zend_Paginator(new Zend_Paginator_Adapter_Null($count));
$paginator->setCurrentPageNumber($currpage);
$this->view->paginator = $paginator;
- $this->view->files = StoredFile::searchFiles($md, $order, false, $paginator->getCurrentPageNumber(), $paginator->getItemCountPerPage());
+ $this->view->files = StoredFile::searchFiles($md, $order, false, $paginator->getCurrentPageNumber(), $paginator->getItemCountPerPage(), $quick);
}
public function editFileMdAction()
@@ -193,6 +208,9 @@ class LibraryController extends Zend_Controller_Action
$this->_helper->viewRenderer->setResponseSegment('quick_search');
+ //$this->view->urlparams = array("route" => array("controller"=> "Library", "action"=> "index", "module"=> "default"));
+ $this->route = 'quick_search';
+
$search = $this->_getParam('search', null);
$format = $this->_getParam('format', 'layout');
@@ -204,26 +222,26 @@ class LibraryController extends Zend_Controller_Action
$md = array();
- $i = 0;
- foreach($keywords as $word) {
-
- foreach($categories as $cat) {
- $md["row_".$i]["metadata_".$i] = $cat;
- $md["row_".$i]["match_".$i] = 0;
- $md["row_".$i]["search_".$i] = $word;
-
- $i = $i + 1;
- }
- }
+ for($group_id=1; $group_id <= count($keywords); $group_id++) {
+
+ for($row_id=1; $row_id <= count($categories); $row_id++) {
+ $md["group_".$group_id]["row_".$row_id]["metadata"] = $categories[$row_id-1];
+ $md["group_".$group_id]["row_".$row_id]["match"] = "0";
+ $md["group_".$group_id]["row_".$row_id]["search"] = $keywords[$group_id-1];
+ }
+ }
+
+ $this->search_sess->quick = $md;
+
$currpage = isset($this->search_sess->page) ? $this->search_sess->page : null;
$order = isset($this->search_sess->order) ? $this->search_sess->order : null;
- $count = StoredFile::searchFiles($md, $order, true);
+ $count = StoredFile::searchFiles($md, $order, true, null, null, true);
$paginator = new Zend_Paginator(new Zend_Paginator_Adapter_Null($count));
$paginator->setCurrentPageNumber($currpage);
$this->view->paginator = $paginator;
- $this->view->files = StoredFile::searchFiles($md, $order, false, $paginator->getCurrentPageNumber(), $paginator->getItemCountPerPage());
+ $this->view->files = StoredFile::searchFiles($md, $order, false, $paginator->getCurrentPageNumber(), $paginator->getItemCountPerPage(), true);
$this->view->html = $this->view->render('library/contents.phtml');
unset($this->view->files);
diff --git a/application/models/StoredFile.php b/application/models/StoredFile.php
index 3812ab5be..5805a7c87 100644
--- a/application/models/StoredFile.php
+++ b/application/models/StoredFile.php
@@ -1741,7 +1741,7 @@ class StoredFile {
return $CC_CONFIG['accessDir']."/$p_token.$p_ext";
}
- public static function searchFiles($md, $order=NULL, $count=false, $page=null, $limit=null)
+ public static function searchFiles($md, $order=NULL, $count=false, $page=null, $limit=null, $quick=false)
{
global $CC_CONFIG, $CC_DBC, $g_metadata_xml_to_db_mapping;
@@ -1800,6 +1800,8 @@ class StoredFile {
$sql = $selector." ".$from;
$or_cond = array();
+ $inner = $quick ? 'OR':'AND';
+ $outer = $quick ? 'AND':'OR';
foreach (array_keys($md) as $group) {
if(strpos($group, 'group') === false) {
@@ -1822,12 +1824,12 @@ class StoredFile {
}
if(count($and_cond) > 0) {
- $or_cond[] = "(".join(" AND ", $and_cond).")";
+ $or_cond[] = "(".join(" ".$inner." ", $and_cond).")";
}
}
if(count($or_cond) > 0) {
- $where = " WHERE ". join(" OR ", $or_cond);
+ $where = " WHERE ". join(" ".$outer." ", $or_cond);
$sql = $sql . $where;
}
@@ -1850,7 +1852,7 @@ class StoredFile {
$sql = $sql . $paginate;
}
//echo var_dump($md);
- echo $sql;
+ //echo $sql;
return $CC_DBC->getAll($sql);
}
diff --git a/public/js/campcaster/library/quicksearch.js b/public/js/campcaster/library/quicksearch.js
index b19b6e03e..a0cd26754 100644
--- a/public/js/campcaster/library/quicksearch.js
+++ b/public/js/campcaster/library/quicksearch.js
@@ -8,7 +8,15 @@ function setUpQuickSearch() {
string = $(this).val();
$.post(url, {search: string}, function(json){
- var x;
+ var html;
+ //hacky way until I can figure out paginator better.
+ html = json.html.replace(/quick-search\/format\/json/g, "index");
+
+ $("#library_content")
+ .empty()
+ .append(html);
+
+ setUpLibrary();
});
});
From ee0a8310de68647366680557cd70a27298ccd836 Mon Sep 17 00:00:00 2001
From: naomiaro
Date: Thu, 6 Jan 2011 01:00:33 -0500
Subject: [PATCH 16/22] small problem with order, quicksearch working, code
could be better.
---
application/models/StoredFile.php | 4 ++--
application/views/scripts/library/paginator.phtml | 8 ++++----
public/js/campcaster/library/quicksearch.js | 15 ++++++++++-----
3 files changed, 16 insertions(+), 11 deletions(-)
diff --git a/application/models/StoredFile.php b/application/models/StoredFile.php
index 5805a7c87..527840a26 100644
--- a/application/models/StoredFile.php
+++ b/application/models/StoredFile.php
@@ -1838,11 +1838,11 @@ class StoredFile {
}
if(!is_null($order)) {
- $ob = " ORDER BY ".$g_metadata_xml_to_db_mapping[$order["category"]]. ", id " .$order["order"];
+ $ob = " ORDER BY ".$g_metadata_xml_to_db_mapping[$order["category"]]." ".$order["order"].", id ";
$sql = $sql . $ob;
}
else{
- $ob = " ORDER BY artist_name, id asc";
+ $ob = " ORDER BY artist_name asc, id";
$sql = $sql . $ob;
}
diff --git a/application/views/scripts/library/paginator.phtml b/application/views/scripts/library/paginator.phtml
index 3e2c78656..95bf42d87 100644
--- a/application/views/scripts/library/paginator.phtml
+++ b/application/views/scripts/library/paginator.phtml
@@ -1,10 +1,10 @@
+
pageCount): ?>
-
+
firstItemNumber; ?> - lastItemNumber; ?>
of totalItemCount; ?>
-
diff --git a/pypo/api_clients/api_client.py b/pypo/api_clients/api_client.py
index 4549b6781..b5b700422 100644
--- a/pypo/api_clients/api_client.py
+++ b/pypo/api_clients/api_client.py
@@ -20,8 +20,8 @@ from urlparse import urlparse
def api_client_factory(config):
- if config["api_client"] == "campcaster":
- return CampcasterApiClient(config)
+ if config["api_client"] == "airtime":
+ return AirTimeApiClient(config)
elif config["api_client"] == "obp":
return ObpApiClient(config)
else:
@@ -100,15 +100,15 @@ class ApiClientInterface:
# nil
################################################################################
# Campcaster API Client
################################################################################
-class CampcasterApiClient(ApiClientInterface):
+class AirTimeApiClient(ApiClientInterface):
def __init__(self, config):
self.config = config
- def __get_campcaster_version(self, verbose = True):
+ def __get_airtime_version(self, verbose = True):
logger = logging.getLogger()
url = self.config["base_url"] + self.config["api_base"] + self.config["version_url"]
url = url.replace("%%api_key%%", self.config["api_key"])
@@ -120,7 +120,7 @@ class CampcasterApiClient(ApiClientInterface):
logger.debug("Data: %s", data)
response_json = json.read(data)
version = response_json['version']
- logger.debug("Campcaster Version %s detected", version)
+ logger.debug("Airtime Version %s detected", version)
except Exception, e:
try:
if e[1] == 401:
@@ -137,7 +137,7 @@ class CampcasterApiClient(ApiClientInterface):
if e[1] == 404:
if (verbose):
print '#####################################'
- print '# Unable to contact the Campcaster-API'
+ print '# Unable to contact the Airtime-API'
print '# ' + url
print '#####################################'
return False
@@ -145,7 +145,7 @@ class CampcasterApiClient(ApiClientInterface):
pass
version = 0
- logger.error("Unable to detect Campcaster Version - %s, Response: %s", e, response)
+ logger.error("Unable to detect Airtime Version - %s, Response: %s", e, response)
return version
@@ -168,22 +168,22 @@ class CampcasterApiClient(ApiClientInterface):
def is_server_compatible(self, verbose = True):
- version = self.__get_campcaster_version(verbose)
+ version = self.__get_airtime_version(verbose)
if (version == 0 or version == False):
if (verbose):
- print 'Unable to get Campcaster version number.'
+ print 'Unable to get Airtime version number.'
print
return False
elif (version[0:4] != "1.6."):
if (verbose):
- print 'Campcaster version: ' + str(version)
- print 'pypo not compatible with this version of Campcaster.'
+ print 'Airtime version: ' + str(version)
+ print 'pypo not compatible with this version of Airtime.'
print
return False
else:
if (verbose):
- print 'Campcaster version: ' + str(version)
- print 'pypo is compatible with this version of Campcaster.'
+ print 'Airtime version: ' + str(version)
+ print 'pypo is compatible with this version of Airtime.'
print
return True
@@ -100,15 +100,15 @@ class ApiClientInterface:
# nil
################################################################################
-# Campcaster API Client
+# Airtime API Client
################################################################################